@@ -3,7 +3,11 @@ mod querier;
 mod query;
 mod route;
 
-pub use msg::{create_batch_update_orders_msg, DerivativeOrder, InjectiveMsg, InjectiveMsgWrapper, OrderData, SpotOrder};
+pub use msg::{
+    create_batch_update_orders_msg, create_derivative_market_order_msg, create_subaccount_transfer_msg, DerivativeOrder, InjectiveMsg,
+    InjectiveMsgWrapper, OrderData, SpotOrder,
+};
+
 pub use querier::InjectiveQuerier;
 pub use query::{
     Deposit, DerivativeLimitOrder, DerivativeMarket, EffectivePosition, InjectiveQuery, InjectiveQueryWrapper, PerpetualMarketFunding,
